# ET: Easy Translation

A quick Chinese<->English translation tool under terminal

## Getting Started

### Prerequisites
+ Get [python](https://www.python.org/) and pip(https://pypi.org/project/pip/) installed

### Installing
```
pip install easy-translation
```

![usage](assets/test-et.gif)

### Usage
```
➜  ~ et 二氧化碳
carbon dioxide
➜  ~ et origin
起源
```

## Contributing

Please read [CONTRIBUTING.md](https://gist.github.com/PurpleBooth/b24679402957c63ec426) for details on our code of conduct, and the process for submitting pull requests to us.

## License

This project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details

## Todo:
- [ ] Glossary Persistence
- [ ] Export Glossary
- [ ] Support file: et -f '测试.txt'